package App::ZodiacUtils::Lite;

our $DATE = '2020-01-01'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: CLI utilities related to zodiac (Perinci::CmdLine::Lite version)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ZodiacUtils::Lite - CLI utilities related to zodiac (Perinci::CmdLine::Lite version)

=head1 VERSION

This document describes version 0.002 of App::ZodiacUtils::Lite (from Perl distribution App-ZodiacUtils-Lite), released on 2020-01-01.

=head1 DESCRIPTION

This distribution is only for testing (originally, to test
L<Dist::Zilla::Plugin::Rinci::AddPrereqs>).

This distribution includes the following CLI utilities:

=over

=item * L<chinese-zodiac-of-lite>

=item * L<zodiac-of-lite>

=back

They are L<Perinci::CmdLine::Lite>-based versions of the same CLI utilities
distributed in L<App::ZodiacUtils> (which are
L<Perinci::CmdLine::Inline>-based).

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ZodiacUtils-Lite>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-ZodiacUtils-Lite>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ZodiacUtils-Lite>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::ZodiacUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
